pub enum IntentData {
Transparent {
request_sha256: String,
confidence: f64,
capabilities: Vec<String>,
magpie_source: Option<String>,
continuation_token: Option<ContinuationToken>,
metadata: SchemaValue,
},
Shadow {
commitment_hash: String,
stark_proof_b64: String,
public_inputs: SchemaValue,
circuit_id: Option<String>,
continuation_token: Option<ContinuationToken>,
metadata: SchemaValue,
},
}Expand description
Intent Data (VEX Pillar) Proves the proposed action before execution. It supports two variants:
- Transparent: Standard human-readable reasoning (Standard).
- Shadow: STARK-proofed hidden intent for privacy (High-Compliance).
Variants
Transparent
Fields

continuation_token: Option<ContinuationToken>Phase 6: Continuation authorization

metadata: SchemaValueCatch-all for extra fields to preserve binary parity in JCS.
Shadow
Fields

public_inputs: SchemaValue
continuation_token: Option<ContinuationToken>Phase 6: Continuation authorization

metadata: SchemaValueCatch-all for extra fields to preserve binary parity in JCS.
Implementations
Sourceimpl IntentData
impl IntentData
pub fn continuation_token(&self) -> Option<&ContinuationToken>
pub fn circuit_id(&self) -> Option<String>
pub fn metadata(&self) -> &SchemaValue
Sourceimpl IntentData
impl IntentData
pub fn to_jcs_hash(&self) -> Result<Hash, String>
Sourcepub fn verify_shadow(&self, verifier: &dyn ZkVerifier) -> Result<bool, ZkError>
pub fn verify_shadow(&self, verifier: &dyn ZkVerifier) -> Result<bool, ZkError>
Verifies the Zero-Knowledge proof for Shadow intents. For Transparent intents, this always returns Ok(true).
Sourcepub fn shadow_public_inputs(&self) -> Result<ShadowPublicInputs, ZkError>
pub fn shadow_public_inputs(&self) -> Result<ShadowPublicInputs, ZkError>
Accesses the typed ShadowPublicInputs for a Shadow intent.