pub struct StreamFinalProof {
pub stream_id: String,
pub receipts: Vec<VexReceipt>,
pub aggregate_proof_b64: String,
}Expand description
An Aggregate Proof for a sequence of authorized transitions. Used to prove the final state of a multi-step governed stream.
Fields
stream_id: Stringreceipts: Vec<VexReceipt>aggregate_proof_b64: StringTrait Implementations
Sourceimpl Clone for StreamFinalProof
impl Clone for StreamFinalProof
Sourcefn clone(&self) -> StreamFinalProof
fn clone(&self) -> StreamFinalProof
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for StreamFinalProof
impl ComposeSchema for StreamFinalProof
Sourceimpl Debug for StreamFinalProof
impl Debug for StreamFinalProof
Sourceimpl<'de> Deserialize<'de> for StreamFinalProof
impl<'de> Deserialize<'de> for StreamFinalProof
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StreamFinalProof
impl PartialEq for StreamFinalProof
Sourceimpl Serialize for StreamFinalProof
impl Serialize for StreamFinalProof
Sourceimpl ToSchema for StreamFinalProof
impl ToSchema for StreamFinalProof
impl StructuralPartialEq for StreamFinalProof